==> qsstv_7.1.7.orig.tar.gz: qsstv-7.1.7/src/configparams.h <==
#ifndef CONFIGPARAMS_H
#define CONFIGPARAMS_H
#include "sstvparam.h"


extern QString rxImagesPath;
extern QString txImagesPath;
extern QString templatesPath;
extern QString docPath;
extern QString audioPath;
extern QString defaultImageFormat;
extern int samplingrate;
extern double rxClock;
extern double txClock;
extern QString inputAudioDevice;
extern QString outputAudioDevice;
extern QString serialPort; /**<  serial port device*/
extern QString radioModel;
extern int radioModelNumber;
extern int civAddress;
extern int baudrate; /**<  serial port baudrate*/
extern QString parity;
extern int stopbits;
extern int databits;
extern QString handshake;
extern bool enableCAT;
extern bool enableSerialPTT;
extern QString pttSerialPort;


extern QString myCallsign;
extern QString myQth;
extern QString myLocator;
extern QString myLastname;
extern QString myFirstname;

extern QString cwText;
extern int cwTone;
extern int cwWPM;
extern bool enableFTP;
extern int ftpPort;
extern QString ftpRemoteHost;
extern QString ftpRemoteDirectory;
extern QString ftpLogin;
extern QString ftpPassword;
extern QString ftpFilename;
extern QString ftpDefaultImageFormat;
extern bool repeaterEnable;
extern int repeaterImageInterval;
extern esstvMode repeaterTxMode;
extern QString repeaterImage1;
extern QString repeaterImage2;
extern QString repeaterImage3;
extern QString repeaterImage4;
extern QString repeaterAcknowledge;
extern QString repeaterTemplate;
extern QString idleTemplate;

extern QString videoDevice;
//extern int framesPerSecondIndex;
extern int colorFormatIndex;
extern int sizeIndex;
extern int channelNumber;
#endif // CONFIGPARAMS_H

==> qsstv_8.2.7.orig.tar.gz: qsstv_8.2.7/src/configparams.h <==
#ifndef CONFIGPARAMS_H
#define CONFIGPARAMS_H
#include "sstv/sstvparam.h"
#include "drmprofileform.h"
#include <QString>

#define NUMFTPRXIMAGES 30

extern QString rxImagesPath;
extern QString txImagesPath;
extern QString templatesPath;
extern QString audioPath;
extern QString docURL;
extern QString defaultImageFormat;
//extern QString fontString;
//extern int fontSize;
extern int samplingrate;
extern double rxClock;
extern double txClock;
extern QString serialPort; /**<  serial port device*/
extern QString radioModel;
extern int radioModelNumber;
extern int civAddress;
extern int baudrate; /**<  serial port baudrate*/
extern QString parity;
extern int stopbits;
extern int databits;
extern QString handshake;
extern bool enableCAT;
//extern bool enableSerialPTT;
extern QString pttSerialPort;


extern QString myCallsign;
extern QString myQth;
extern QString myLocator;
extern QString myLastname;
extern QString myFirstname;

extern QString cwText;
extern int cwTone;
extern int cwWPM;


extern bool enableFTP;
extern int ftpPort;
extern QString ftpRemoteHost;
extern QString ftpRemoteDirectory;
extern QString ftpLogin;
extern QString ftpPassword;
extern QString ftpFilename;
extern QString ftpDefaultImageFormat;
extern bool enableHybridRx;
extern bool enableSpecialServer;
extern int hybridFtpPort;
extern QString hybridFtpRemoteHost;
extern QString hybridFtpRemoteDirectory;

extern QString hybridFtpLogin;
extern QString hybridFtpPassword;
extern bool useHybrid;
enum eftpSaveFormat {FTPIM,FTPFILE};
extern eftpSaveFormat ftpSaveFormat;
extern bool repeaterEnable;
extern int repeaterImageInterval;
extern esstvMode repeaterTxMode;
extern QString repeaterImage1;
extern QString repeaterImage2;
extern QString repeaterImage3;
extern QString repeaterImage4;
extern QString repeaterAcknowledge;
extern QString repeaterTemplate;
extern QString idleTemplate;

extern QString startPicWF;
extern QString endPicWF;
extern QString fixWF;
extern QString bsrWF;
extern QString drmCallsign;
extern drmProfileForm *drmProfilePtr;


extern QString videoDevice;
//extern int framesPerSecondIndex;
extern int colorFormatIndex;
extern int sizeIndex;
extern int channelNumber;
extern etransmissionMode transmissionModeIndex;  // SSTV , DRM or FAX
extern unsigned int dataScopeOffset;
#endif // CONFIGPARAMS_H
